@@ -187,6 +187,21 @@ def retry_node(runtime: EngineRuntimeInterface, node_id: str, data: Optional[dic
     Engine(runtime).retry_node(node_id, data)
 
 
+@_ensure_return_api_result
+def retry_subprocess(runtime: EngineRuntimeInterface, node_id: str) -> EngineAPIResult:
+    """
+    重试进入失败的子流程节点
+
+    :param runtime: 引擎运行时实例
+    :type runtime: EngineRuntimeInterface
+    :param node_id: 子流程节点 id
+    :type node_id: str
+    :return: [description]
+    :rtype: EngineAPIResult
+    """
+    Engine(runtime).retry_subprocess(node_id)
+
+
 @_ensure_return_api_result
 def skip_node(runtime: EngineRuntimeInterface, node_id: str) -> EngineAPIResult:
     """
